@@ -1,32 +1,54 @@
 package Dist::Zilla::Plugin::MakeMaker;
 BEGIN {
-  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.101612';
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.200000';
 }
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::BuildRunner';
 with 'Dist::Zilla::Role::PrereqSource';
 with 'Dist::Zilla::Role::InstallTool';
-with 'Dist::Zilla::Role::TestRunner';
 with 'Dist::Zilla::Role::TextTemplate';
 
 
 use Config;
 
+has 'make_path' => (
+  isa => 'Str',
+  is  => 'ro',
+  default => $Config{make} || 'make',
+);
+
+has '_runner' => (
+  is   => 'ro',
+  lazy => 1,
+  handles => [qw(build test)],
+  default => sub {
+    my ($self) = @_;
+    Dist::Zilla::Plugin::MakeMaker::Runner->new({
+      zilla       => $self->zilla,
+      plugin_name => $self->plugin_name . '::Runner',
+      make_path   => $self->make_path,
+    });
+  },
+);
+
+with 'Dist::Zilla::Role::BuildRunner';
+with 'Dist::Zilla::Role::TestRunner';
+
 use Data::Dumper ();
 use List::MoreUtils qw(any uniq);
 
 use namespace::autoclean;
 
 use Dist::Zilla::File::InMemory;
+use Dist::Zilla::Plugin::MakeMaker::Runner;
 
 my $template = q|
 use strict;
 use warnings;
 
-{{ $perl_prereq ? qq{ BEGIN { require $perl_prereq; } } : ''; }}
+{{ $perl_prereq ? qq[BEGIN { require $perl_prereq; }] : ''; }}
 
 use ExtUtils::MakeMaker {{ $eumm_version }};
 
@@ -64,7 +86,7 @@ sub register_prereqs {
     'ExtUtils::MakeMaker' => $self->eumm_version,
   );
 
-  return unless $self->zilla->_share_dir;
+  return unless keys %{ $self->zilla->_share_dir_map };
 
   $self->zilla->register_prereqs(
     { phase => 'configure' },
@@ -93,10 +115,25 @@ sub setup_installer {
 
   my @share_dir_block = (q{}, q{});
 
-  if (my $share_dir = $self->zilla->_share_dir) {
-    my $share_dir = quotemeta $share_dir;
+
+  my $share_dir_map = $self->zilla->_share_dir_map;
+  if ( keys %$share_dir_map ) {
+    my $preamble = qq{use File::ShareDir::Install;\n};
+
+    if ( my $dist_share_dir = $share_dir_map->{dist} ) {
+      $dist_share_dir = quotemeta $dist_share_dir;
+      $preamble .= qq{install_share dist => "$dist_share_dir";\n};
+    }
+
+    if ( my $mod_map = $share_dir_map->{module} ) {
+      for my $mod ( keys %$mod_map ) {
+        my $mod_share_dir = quotemeta $mod_map->{$mod};
+        $preamble .= qq{install_share module => "$mod", "$mod_share_dir";\n};
+      }
+    }
+
     @share_dir_block = (
-      qq{use File::ShareDir::Install;\ninstall_share "$share_dir";\n},
+      $preamble,
       qq{package\nMY;\nuse File::ShareDir::Install qw(postamble);\n},
     );
   }
@@ -168,32 +205,6 @@ has __write_makefile_args => (
   isa  => 'HashRef',
 );
 
-has 'make_path' => (
-  isa => 'Str',
-  is  => 'ro',
-  default => $Config{make} || 'make',
-);
-
-sub build {
-  my $self = shift;
-
-  my $make = $self->make_path;
-  system($^X => 'Makefile.PL') and die "error with Makefile.PL\n";
-  system($make)                and die "error running $make\n";
-
-  return;
-}
-
-sub test {
-  my ( $self, $target ) = @_;
-
-  my $make = $self->make_path;
-  $self->build;
-  system($make, 'test') and die "error running $make test\n";
-
-  return;
-}
-
 has 'eumm_version' => (
   isa => 'Str',
   is  => 'rw',
@@ -213,7 +224,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 4.101612
+version 4.200000
 
 =head1 DESCRIPTION
 
@@ -223,7 +234,7 @@ plugin should also be loaded.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
