@@ -1,22 +1,52 @@
 package Dist::Zilla::Plugin::PruneCruft;
 BEGIN {
-  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.101900';
+  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.200000';
 }
 # ABSTRACT: prune stuff that you probably don't mean to include
 use Moose;
 use Moose::Autobox;
+use Moose::Util::TypeConstraints;
 with 'Dist::Zilla::Role::FilePruner';
 
 
-# sub mvp_multivalue_args { qw(file) }
+{
+  my $type = subtype as 'ArrayRef[RegexpRef]';
+  coerce $type, from 'ArrayRef[Str]', via { [map { qr/$_/ } @$_] };
+  has except => (
+    is      => 'ro',
+    isa     => $type,
+    coerce  => 1,
+    default => sub { [] },
+  );
+  sub mvp_multivalue_args { qw(except) }
+}
+
+sub _dont_exclude_file {
+  my ($self, $file) = @_;
+  for my $exception ($self->except->flatten) {
+    return 1 if $file->name =~ $exception;
+  }
+  return;
+}
 
 sub exclude_file {
   my ($self, $file) = @_;
 
+  return 0 if $self->_dont_exclude_file($file);
   return 1 if index($file->name, $self->zilla->name . '-') == 0;
   return 1 if $file->name =~ /\A\./;
   return 1 if $file->name =~ /\A(?:Build|Makefile)\z/;
+  return 1 if $file->name =~ /\Ablib/;
+  return 1 if $file->name =~ /\.(?:o|bs)$/;
   return 1 if $file->name eq 'MYMETA.yml';
+  return 1 if $file->name eq 'pm_to_blib';
+
+  if ((my $file = $file->name) =~ s/\.c$//) {
+      for my $other ($self->zilla->files->flatten) {
+          return 1 if $other->name eq "${file}.xs";
+      }
+  }
+
   return;
 }
 
@@ -47,7 +77,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 4.101900
+version 4.200000
 
 =head1 SYNOPSIS
 
@@ -59,8 +89,12 @@ In your F<dist.ini>:
 
   [PruneCruft]
 
-That's it!  Maybe some day there will be a mechanism for excluding exclusions,
-but for now that exclusion exclusion mechanism has been excluded.
+If you would like to exclude certain exclusions, use the C<except> option (it
+can be specified multiple times):
+
+  [PruneCruft]
+  except = \.gitignore
+  except = t/.*/\.keep$
 
 =head1 AUTHOR
 
