@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::TemplateModule;
 BEGIN {
-  $Dist::Zilla::Plugin::TemplateModule::VERSION = '4.101612';
+  $Dist::Zilla::Plugin::TemplateModule::VERSION = '4.200000';
 }
 # ABSTRACT: a simple module-from-template plugin
 use Moose;
@@ -36,6 +36,7 @@ sub make_module {
   my $content = $self->fill_in_string(
     $template,
     {
+      dist => \($self->zilla),
       name => $arg->{name},
     },
   );
@@ -63,15 +64,16 @@ Dist::Zilla::Plugin::TemplateModule - a simple module-from-template plugin
 
 =head1 VERSION
 
-version 4.101612
+version 4.200000
 
 =head1 DESCRIPTION
 
 This is a L<ModuleMaker|Dist::Zilla::Role::ModuleMaker> used for creating new
 Perl modules files when minting a new dist with C<dzil new>.  It uses
 L<Text::Template> (via L<Dist::Zilla::Role::TextTemplate>) to render a template
-into a Perl module.  The only variable provided to the template is C<$name>,
-the module name.  The module is always created as a file under F<./lib>.
+into a Perl module.  The template is given two variables for use in rendering:
+C<$name>, the module name; and C<$dist>, the Dist::Zilla object.  The module is
+always created as a file under F<./lib>.
 
 By default, the template looks something like this:
 
@@ -90,7 +92,7 @@ filename, absolute or relative to the build root.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
